# Top namespace
module LabClient
  # Specifics
  class Files < Common
    doc 'Show' do
      desc 'Allows you to receive information about file in repository like name, size, content [Project ID, File Path, Ref (master default), kind]'
      example 'client.files.show(264, "README.md")'

      markdown <<~DOC
        Ref will default to `master`

        Kind can be left empty or set to either :raw or :blame
      DOC
    end

    doc 'Show' do
      desc 'Raw Content'
      example 'client.files.show(264, "README.md", :master, :raw)'
    end

    doc 'Show' do
      desc 'Blame'
      example 'client.files.show(264, "README.md", :master, :blame)'
    end

    doc 'Show' do
      desc 'via Project'
      example <<~DOC
        project = client.projects.show(264)
        project.file('a3c86df3f')
      DOC
    end

    def show(project_id, file_path, ref = :master, kind = nil)
      kind = case kind
             when :raw
               '/raw'
             when :blame
               '/blame'
             end
      # GET /projects/:id/repository/files/:file_path

      project_id = format_id(project_id)

      # Path Name Encoding
      file_path = CGI.escape(file_path)

      client.request(:get, "projects/#{project_id}/repository/files/#{file_path}#{kind}", nil, ref: ref)
    end
  end
end
