# Top namespace
module LabClient
  # Specifics
  class Jobs < Common
    doc 'Artifacts' do
      desc 'Get the job’s artifacts zipped archive of a project. [Project ID, Job ID, File Path, Job Token]'
      example 'client.jobs.artifacts(264, 1)'

      markdown <<~DOC
        File Output will default to the current directory + job id + file extension. 14.zip

        Job Token: To be used with triggers for multi-project pipelines. It should be invoked only inside `.gitlab-ci.yml`. Its value is always `$CI_JOB_TOKEN`.
      DOC
    end

    doc 'Artifacts' do
      desc 'Specific output location'
      example <<~DOC
        client.jobs.artifacts(264, 1, '/tmp/output.zip')
      DOC
    end

    doc 'Artifacts' do
      desc 'via Project'
      example <<~DOC
        project = client.projects.show(264)
        project.job_artifacts(7)
      DOC
    end

    doc 'Artifacts' do
      desc 'via Job'
      example <<~DOC
        job = client.jobs.show(264, 7)
        job.artifacts
      DOC
    end

    def artifacts(project_id, job_id, file_path = nil, job_token = nil)
      job_id = format_id(job_id)
      project_id = format_id(project_id)
      file_path ||= "#{Dir.pwd}/#{job_id}.zip"
      query = { job_token: job_token } if job_token
      output = client.request(:get, "projects/#{project_id}/jobs/#{job_id}/artifacts", nil, query)

      File.write(file_path, output)
    end
  end
end
